#pragma once

// Defines the possible output modes.
enum vdc_output_mode_t {
	VDC_OUTPUT_TV,
	VDC_OUTPUT_LCD,
	VDC_OUTPUT_VGA,
};

// Defines a rectangle.
struct vdc_rectangle_t {
	int left;
	int top;
	int right;
	int bottom;
};

// Defines a 2D point.
struct vdc_point_2d_t {
	int x;
	int y;
};

// Stores a 320x240 monochrome bitmap.
extern unsigned int __attribute__((far,noload)) vdc_frame_buffer[4800];

// Stores the current frame rate of the display refresh.
extern int vdc_fps;

// (TV specific) offsets the display in the X axis.
extern int vdc_tv_line_offset_x;

// (TV specific) offsets the display in the Y axis.
extern int vdc_tv_line_offset_y;

// Resets both graphics and text systems. This does not (re)initialise output.
void vdc_reset(void);

// Initialises the VDC library.
void vdc_init_output(enum vdc_output_mode_t vdc_output_mode);

// Automatically (re)initises the VDC to output to the TV (if connected) or the LCD (if not).
void vdc_auto_init_output(void);

// Checks whether a TV is connected or not. May only be updated once a frame.
int vdc_tv_is_connected(void);

// Waits for the display to finish retracing and enter the vertical blank region.
void vdc_wait_vblank(void);

// Delay for a particular number of frames.
void vdc_delay_frames(int frames);

// Stores the current output mode.
extern enum vdc_output_mode_t vdc_output_mode;
